==> hlw-core-0.0.2-20250513.033334-23-sources.jar: cn/gtmap/hlw/core/dto/sqxx/lqxx/LqxxQueryResultDTO.java <==
package cn.gtmap.hlw.core.dto.sqxx.lqxx;

import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:wangzhiwen@gtmap.cn">wangzhiwen</a>
 * @version 2024/6/27 19:30
 * @description 林权分页查询结果
 */
@Data
public class LqxxQueryResultDTO {

    /**
     * 产权证号
     */
    private String cqzh;
    /**
     * 不动产单元号
     */
    private String bdcdyh;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 面积
     */
    private String mj;
    /**
     * 是否抵押（0是，1否）
     */
    private String sfdy;
    /**
     * 是否查封（0是，1否）
     */
    private String sfcf;
    /**
     * 地籍号
     */
    private String djh;
    /**
     * 林种
     */
    private String lz;
    /**
     * 权利类型
     */
    private String qllx;
    /**
     * 权利类型名称
     */
    private String qllxmc;
    /**
     * 林地使用开始期限
     */
    private String ldsyksqx;
    /**
     * 林地使用结束期限
     */
    private String ldsyjsqx;
    /**
     * 林班
     */
    private String lb;
    /**
     * 小班
     */
    private String xb;
    /**
     * 造林年度
     */
    private String zlnd;
    /**
     * 株数
     */
    private String zs;
    /**
     * 主要树种
     */
    private String zysz;
    /**
     * 权属状态
     */
    private String qszt;
    /**
     * 附记
     */
    private String fj;
    /**
     * 异议状态 是否异议（0是，1否）
     */
    private String sfyy;
    /**
     * 锁定状态 是否锁定（0是，1否）
     */
    private String sfsd;
    /**
     * 预告状态 是否预告（0是，1否）
     */
    private String sfyg;
    /**
     * 项目id
     */
    private String xmid;
    /**
     * 林地使用期限是否永久
     */
    private String ldsyqxsfyj;
    /**
     * 森林类别代码
     */
    private String sllbdm;
    /**
     * 森林类别名称
     */
    private String sllbmc;
    /**
     * 事权等级
     */
    private String sqdj;
    /**
     * 小地名
     */
    private String xdm;
    /**
     * 起源
     */
    private String qy;
    /**
     * 权利人信息
     */
    private List<LqxxQueryQlrxxResultDTO> qlrList;


}

==> hlw-core-0.0.2-20251205.085720-174-sources.jar: cn/gtmap/hlw/core/dto/sqxx/lqxx/LqxxQueryResultDTO.java <==
package cn.gtmap.hlw.core.dto.sqxx.lqxx;

import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:wangzhiwen@gtmap.cn">wangzhiwen</a>
 * @version 2024/6/27 19:30
 * @description 林权分页查询结果
 */
@Data
public class LqxxQueryResultDTO {

    /**
     * 产权证号
     */
    private String cqzh;
    /**
     * 不动产单元号
     */
    private String bdcdyh;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 面积
     */
    private String mj;
    /**
     * 是否抵押（0是，1否）
     */
    private String sfdy;
    /**
     * 是否查封（0是，1否）
     */
    private String sfcf;
    /**
     * 地籍号
     */
    private String djh;
    /**
     * 林种
     */
    private String lz;
    /**
     * 权利类型
     */
    private String qllx;
    /**
     * 权利类型名称
     */
    private String qllxmc;
    /**
     * 林地使用开始期限
     */
    private String ldsyksqx;
    /**
     * 林地使用结束期限
     */
    private String ldsyjsqx;
    /**
     * 林班
     */
    private String lb;
    /**
     * 小班
     */
    private String xb;
    /**
     * 造林年度
     */
    private String zlnd;
    /**
     * 株数
     */
    private String zs;
    /**
     * 主要树种
     */
    private String zysz;
    /**
     * 权属状态
     */
    private String qszt;
    /**
     * 附记
     */
    private String fj;
    /**
     * 异议状态 是否异议（0是，1否）
     */
    private String sfyy;
    /**
     * 锁定状态 是否锁定（0是，1否）
     */
    private String sfsd;
    /**
     * 预告状态 是否预告（0是，1否）
     */
    private String sfyg;
    /**
     * 项目id
     */
    private String xmid;
    /**
     * 林地使用期限是否永久
     */
    private String ldsyqxsfyj;
    /**
     * 森林类别代码
     */
    private String sllbdm;
    /**
     * 森林类别名称
     */
    private String sllbmc;
    /**
     * 事权等级
     */
    private String sqdj;
    /**
     * 小地名
     */
    private String xdm;
    /**
     * 起源
     */
    private String qy;
    /**
     * 森林、林木使用权人
     */
    private String sllmsyr;
    /**
     * 森林、林木所有权人
     */
    private String sllmsyqr;
    /**
     * 行政区代码
     */
    private String qydm;
    /**
     * 合同编号
     */
    private String htbh;
    /**
     * 林地所有权性质代码
     */
    private String ldsyqxzdm;
    /**
     * 林地所有权性质名称
     */
    private String ldsyqxzmc;
    /**
     * 登记机构
     */
    private String djjg;
    /**
     * 登簿人
     */
    private String dbr;
    /**
     * 登簿时间
     */
    private String dbsj;
    /**
     * 权利人信息
     */
    private List<LqxxQueryQlrxxResultDTO> qlrList;


}
